==> haskell-test-framework-leancheck-0.0.4-179-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-test-framework-leancheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 test-framework-leancheck
version:              0.0.4
visibility:           public
id:                   test-framework-leancheck-0.0.4-3LSw7MNqmKULurdDLVzubO
key:                  test-framework-leancheck-0.0.4-3LSw7MNqmKULurdDLVzubO
license:              BSD-3-Clause
maintainer:           Rudy Matela <rudy@matela.com.br>
author:               Rudy Matela <rudy@matela.com.br>
homepage:
    https://github.com/rudymatela/test-framework-leancheck#readme

synopsis:             LeanCheck support for test-framework.
description:
    LeanCheck support for test-framework.

    This package can be used to incorporate LeanCheck tests
    into test-framework test suites.

    Please see the Haddock documentation and README for more details.

category:             Testing
abi:                  2ccc05a43b3e2a1890b035faaf4736f6
exposed:              True
exposed-modules:      Test.Framework.Providers.LeanCheck
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/test-framework-leancheck-0.0.4

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/test-framework-leancheck-0.0.4

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/test-framework-leancheck-0.0.4

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-test-framework-leancheck
hs-libraries:         HStest-framework-leancheck-0.0.4-3LSw7MNqmKULurdDLVzubO
depends:
    base-4.17.2.1 leancheck-1.0.2-5Ojvq0ETRbD6kLjzbd6ylR
    test-framework-0.8.2.2-5c2pmkO0p1NArjHmMH8PAg

haddock-interfaces:
    /usr/share/doc/haskell-test-framework-leancheck/html/test-framework-leancheck.haddock

haddock-html:         /usr/share/doc/haskell-test-framework-leancheck/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-test-framework-leancheck-0.0.4-180-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-test-framework-leancheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 test-framework-leancheck
version:              0.0.4
visibility:           public
id:                   test-framework-leancheck-0.0.4-4mUsNqjXpdaLaIO0JIutIi
key:                  test-framework-leancheck-0.0.4-4mUsNqjXpdaLaIO0JIutIi
license:              BSD-3-Clause
maintainer:           Rudy Matela <rudy@matela.com.br>
author:               Rudy Matela <rudy@matela.com.br>
homepage:
    https://github.com/rudymatela/test-framework-leancheck#readme

synopsis:             LeanCheck support for test-framework.
description:
    LeanCheck support for test-framework.

    This package can be used to incorporate LeanCheck tests
    into test-framework test suites.

    Please see the Haddock documentation and README for more details.

category:             Testing
abi:                  6544c1433a887b1e075e4260297a7262
exposed:              True
exposed-modules:      Test.Framework.Providers.LeanCheck
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/test-framework-leancheck-0.0.4

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/test-framework-leancheck-0.0.4

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/test-framework-leancheck-0.0.4

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-test-framework-leancheck
hs-libraries:         HStest-framework-leancheck-0.0.4-4mUsNqjXpdaLaIO0JIutIi
depends:
    base-4.17.2.1 leancheck-1.0.2-5Ojvq0ETRbD6kLjzbd6ylR
    test-framework-0.8.2.2-3wG3CzhhXw62tWOIVqAswu

haddock-interfaces:
    /usr/share/doc/haskell-test-framework-leancheck/html/test-framework-leancheck.haddock

haddock-html:         /usr/share/doc/haskell-test-framework-leancheck/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
